@@ -67,7 +67,7 @@ struct _GcrListSelectorPrivate {
 	GtkWidget *search_widget;
 };
 
-G_DEFINE_TYPE (GcrListSelector, gcr_list_selector, GTK_TYPE_TREE_VIEW);
+G_DEFINE_TYPE_WITH_PRIVATE (GcrListSelector, gcr_list_selector, GTK_TYPE_TREE_VIEW);
 
 static gboolean
 object_is_visible (GcrListSelector *self, GObject *object)
@@ -260,7 +260,7 @@ gcr_list_selector_constructed (GObject *object)
 static void
 gcr_list_selector_init (GcrListSelector *self)
 {
-	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, GCR_TYPE_LIST_SELECTOR, GcrListSelectorPrivate);
+	self->pv = gcr_list_selector_get_instance_private (self);
 }
 
 static void
@@ -341,8 +341,6 @@ gcr_list_selector_class_init (GcrListSelectorClass *klass)
 	gobject_class->set_property = gcr_list_selector_set_property;
 	gobject_class->get_property = gcr_list_selector_get_property;
 
-	g_type_class_add_private (gobject_class, sizeof (GcrListSelectorPrivate));
-
 	/**
 	 * GcrListSelector:collection:
 	 *
